orbital_state library

Classes

OrbitalStateSubscription
Handle returned by StateMixin.listen, used to stop the subscription before the owning object is disposed.

Mixins

StateMixin<T>
Reactive state for OrbitalLifecycle objects via emit.

Exceptions / Errors

OrbitalStateNotEmittedException
Thrown when state, watch or listen runs before the first emit.